@@ -44,7 +44,9 @@ using LDASTools::AL::GPSTime;
 
 typedef unordered_map< std::string, const char* > site_container_type;
 
+#if DEPRICATED
 static const pthread_t main_thread = pthread_self( );
+#endif /* DEPRICATED */
 
 //-----------------------------------------------------------------------
 /// \brief Format gif image appropriate for log entry
@@ -443,15 +445,14 @@ gif_lookup( HTML::message_type MT )
 	}
       };
 
-      gifs[ HTML::MT_OK ] = &gif_info_table[ 0 ];
-      gifs[ HTML::MT_WARN ] = &gif_info_table[ 1 ];
-      gifs[ HTML::MT_ERROR ] = &gif_info_table[ 2 ];
-      gifs[ HTML::MT_EMAIL ] = &gif_info_table[ 3 ];
-      gifs[ HTML::MT_CERTMAIL ] = &gif_info_table[ 4 ];
-      gifs[ HTML::MT_PHONE ] = &gif_info_table[ 5 ];
-      gifs[ HTML::MT_DEBUG ] = &gif_info_table[ 6 ];
-      gifs[ HTML::MT_NOTE ] = &gif_info_table[ 7 ];
-      gifs[ HTML::MT_ORANGE ] = &gif_info_table[ 8 ];
+      gifs[ HTML::MT_OK ] = &gif_info_table[ HTML::MT_OK ];
+      gifs[ HTML::MT_WARN ] = &gif_info_table[ HTML::MT_WARN ];
+      gifs[ HTML::MT_ERROR ] = &gif_info_table[ HTML::MT_ERROR ];
+      gifs[ HTML::MT_EMAIL ] = &gif_info_table[ HTML::MT_EMAIL ];
+      gifs[ HTML::MT_PHONE ] = &gif_info_table[ HTML::MT_PHONE ];
+      gifs[ HTML::MT_DEBUG ] = &gif_info_table[ HTML::MT_DEBUG ];
+      gifs[ HTML::MT_NOTE ] = &gif_info_table[ HTML::MT_NOTE ];
+      gifs[ HTML::MT_ORANGE ] = &gif_info_table[ HTML::MT_ORANGE ];
 
       initialized = true;
     }
